/**
 * Ordinary least squares Linear Regression.
 *
 * @example
 * import { LinearRegression } from './linear_regression';
 * const linearRegression = new LinearRegression();
 * const X = [1, 2, 4, 3, 5];
 * const y = [1, 3, 3, 2, 5];
 * linearRegression.fit({ X, y });
 * console.log(lr.predict([1, 2]));
 * // [ 1.1999999999999995, 1.9999999999999996 ]
 */
export declare class LinearRegression {
    private b0;
    private b1;
    /**
     * fit linear model
     * @param {any} X - training values
     * @param {any} y - target values
     */
    fit({ X, y }: {
        X: number[];
        y: number[];
    }): void;
    /**
     * Predict using the linear model
     * @param {number} X - Values to predict.
     * @returns {number}
     */
    predict(X?: number[]): number[];
    /**
     * Get the model details in JSON format
     */
    toJSON(): {
        /**
         * Coefficients component: b0
         */
        b0: number;
        /**
         * Coefficients component: b1
         */
        b1: number;
    };
    /**
     * Restore the model from a checkpoint
     * @param {number} b0 - Coefficients component: b0
     * @param {number} b1 - Coefficients component: b1
     */
    fromJSON({ b0, b1 }: {
        b0: number;
        b1: number;
    }): void;
    /**
     * Calculates coefficient for linear regression
     * @param X - X values
     * @param y - y targets
     */
    private coefficients;
}
