/**
 * The Naive is an intuitive method that uses probabilistic of each attribute
 * belonged to each class to make a prediction. It uses Gaussian function to estimate
 * probability of a given class.
 *
 * @example
 * import { GaussianNB } from 'kalimdor/naive_bayes';
 *
 * const nb = new GaussianNB();
 * const X = [[1, 20], [2, 21], [3, 22], [4, 22]];
 * const y = [1, 0, 1, 0];
 * nb.fit({ X, y });
 * nb.predict({ X: [[1, 20]] }); // returns [ 1 ]
 *
 */
export declare class GaussianNB {
    /**
     * Naive Bayes summary according to classes
     */
    private summaries;
    /**
     * To clone input values
     */
    private clone;
    /**
     * @param clone - To clone the input values during fit and predict
     */
    constructor({ clone }?: {
        clone: boolean;
    });
    /**
     * Fit date to build Gaussian Distribution summary
     * @param {any} X - training values
     * @param {any} y - target values
     */
    fit({ X, y }?: {
        X: any[][];
        y: any[];
    }): void;
    /**
     * Predict multiple rows
     * @param {any[]} X - values to predict in Matrix format
     * @returns {number[]}
     */
    predict({ X }?: {
        X: any[][];
    }): number[];
    /**
     * Restores GaussianNB model from a checkpoint
     * @param summaries - Gaussian Distribution summaries
     */
    fromJSON({ summaries }?: {
        summaries: {};
    }): void;
    /**
     * Returns a model checkpoint
     */
    toJSON(): {
        summaries: {};
    };
    /**
     * Make a prediction
     * @param X -
     */
    private singlePredict;
    /**
     * Calculate the main division
     * @param x
     * @param meanval
     * @param stdev
     */
    private calculateProbability;
    /**
     * Summarise the dataset per class using "probability density function"
     * example:
     * Given
     * const X = [[1,20], [2,21], [3,22], [4,22]];
     * const y = [1, 0, 1, 0];
     * Returns
     * { '0': [ [ 3, 1.4142135623730951 ], [ 21.5, 0.7071067811865476 ] ],
     * '1': [ [ 2, 1.4142135623730951 ], [ 21, 1.4142135623730951 ] ] }
     * @param dataset
     */
    private summarizeByClass;
    /**
     * Summarise the dataset to calculate the ‘pdf’ (probability density function) later on
     * @param dataset
     */
    private summarize;
    /**
     * Separates X by classes specified by y argument
     * @param X
     * @param y
     */
    private separateByClass;
}
