# ensemble.RandomForestClassifier

Random forest classifier creates a set of decision trees from randomly selected subset of training set.
It then aggregates the votes from different decision trees to decide the final class of the test object.



        
### Usage
            
```javascript
import { RandomForestClassifier } from 'kalimdor/ensemble';

const X = [[0, 0], [1, 1], [2, 1], [1, 5], [3, 2]];
const y = [0, 1, 2, 3, 7];

const randomForest = new RandomForestClassifier();
randomForest.fit({ X, y });

// Results in a value such as [ '0', '2' ].
// Predictions will change as we have not set a seed value.
```

        
### Constructors
            
* [constructor](#constructor)


        
### Methods
            
* [fit](#λ-fit)
            
* [fromJSON](#λ-fromjson)
            
* [predict](#λ-predict)
            
* [toJSON](#λ-tojson)




        
# Constructors
        
---
            
### constructor
            

            


                    
⊕ **new RandomForestClassifier**(__namedParameters: *&#x60;object&#x60;*)
                
Defined in [ensemble/forest.ts:11](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/ensemble/forest.ts#L11)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.nEstimator | number | 10 | Number of trees.
| options.randomstate | number | null | Random seed value for DecisionTrees

                        

                        
**Returns:** RandomForestClassifier






        
# Methods
        
---
                    
### λ fit
                    
Build a forest of trees from the training set (X, y).
                    

                
Defined in [ensemble/forest.ts:43](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/ensemble/forest.ts#L43)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.X | number[][] | [] | array-like or sparse matrix of shape &#x3D; [nsamples, n_features]
| options.y | number[] | [] | array-like, shape &#x3D; [nsamples] or [n_samples, n_outputs]

                        
**Returns:**
                        
void
                    
### λ fromJSON
                    
Restore the model from a checkpoint
                    

                
Defined in [ensemble/forest.ts:74](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/ensemble/forest.ts#L74)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.trees | any[] | null | Decision trees

                        
**Returns:**
                        
void
                    
### λ predict
                    
Predict class for X.
                    
The predicted class of an input sample is a vote by the trees in the forest, weighted by their probability estimates.
That is, the predicted class is the one with highest mean probability estimate across the trees.
                
Defined in [ensemble/forest.ts:119](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/ensemble/forest.ts#L119)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| X | number[] or number[][] | [] | array-like or sparse matrix of shape &#x3D; [nsamples]

                        
**Returns:**
                        
any[]
                    
### λ toJSON
                    
Returning the current model&#x27;s checkpoint
                    

                
Defined in [ensemble/forest.ts:63](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/ensemble/forest.ts#L63)
                


                        
**Returns:**
                        
| Param | Type | Description |
| ------ | ------ | ------ |
| nEstimator | number | undefined
| trees | any[] | undefined


