# preprocessing.Binarizer

Binarizer transform your data using a binary threshold.
All values above the threshold are marked 1 and all equal to or below are marked as 0.
It can also be used as a pre-processing step for estimators that consider
boolean random variables (e.g. modelled using the Bernoulli distribution in
a Bayesian setting).



        
### Usage
            
```javascript
import { Binarizer } from 'kalimdor/preprocessing';

const binX = [[1, -1, 2], [2, 0, 0], [0, 1, -1]];
const binarizer = new Binarizer({ threshold: 0 });
const result = binarizer.transform(binX);
// [ [ 1, 0, 1 ], [ 1, 0, 0 ], [ 0, 1, 0 ] ]
```

        
### Constructors
            
* [constructor](#constructor)


        
### Methods
            
* [fit](#λ-fit)
            
* [transform](#λ-transform)




        
# Constructors
        
---
            
### constructor
            

            


                    
⊕ **new Binarizer**(__namedParameters: *&#x60;object&#x60;*)
                
Defined in [preprocessing/data.ts:468](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/preprocessing/data.ts#L468)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| options.copy | boolean | true | Flag to clone the input value.
| options.threshold | number | 0 | Feature values below or equal to this are replaced by 0, above it by 1.

                        

                        
**Returns:** Binarizer






        
# Methods
        
---
                    
### λ fit
                    
Currently fit does nothing
                    

                
Defined in [preprocessing/data.ts:498](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/preprocessing/data.ts#L498)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| X | any[] | [] | Does nothing

                        
**Returns:**
                        
void
                    
### λ transform
                    
Transforms matrix into binarized form
X &#x3D; [[ 1., -1.,  2.],
     [ 2.,  0.,  0.],
     [ 0.,  1., -1.]]
becomes
array([[ 1.,  0.,  1.],
   [ 1.,  0.,  0.],
   [ 0.,  1.,  0.]])
                    

                
Defined in [preprocessing/data.ts:516](https://github.com/JasonShin/kalimdorjs/blob/master/src/lib/preprocessing/data.ts#L516)
                


                        
**Parameters:**
                        
| Param | Type | Default | Description |
| ------ | ------ | ------ | ------ |
| X | any[] | [] | The data to binarize.

                        
**Returns:**
                        
any[]

