"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
exports.__esModule = true;
var fs = require("fs");
var lodash_1 = require("lodash");
var path = require("path");
var BaseProcesser_1 = require("./BaseProcesser");
var exampleConfig_1 = require("./exampleConfig");
// import * as path from 'path';
var ExampleProcessor = /** @class */ (function (_super) {
    __extends(ExampleProcessor, _super);
    function ExampleProcessor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.vuepressExampleConfigPath = path.join(__dirname, '../md_out/.vuepress/exampleExtra.json');
        _this.themePath = path.join(__dirname, '../themes/markdown');
        _this.exampleOutputPath = path.join(__dirname, '../md_out/examples');
        _this.homePageFile = 'examples_readme.hbs';
        _this.srcExampleHomeTheme = path.join(_this.themePath, _this.homePageFile);
        _this.destExampleHomePage = path.join(__dirname, '../md_out/examples/README.md');
        _this.examplePageFile = 'example_entity_page.hbs';
        _this.srcExamplePageTheme = path.join(_this.themePath, _this.examplePageFile);
        return _this;
    }
    /**
     * Run the processor
     * @param hbs
     */
    ExampleProcessor.prototype.run = function (hbs) {
        this.createDir();
        this.createReadMe(hbs);
        this.createExamplePage(hbs);
        this.createSidebar();
    };
    /**
     * Writes the sidebar config for examples
     */
    ExampleProcessor.prototype.createSidebar = function () {
        var config = exampleConfig_1["default"].map(function (category) {
            var categoryKey = category.key;
            var categoryTitle = category.title;
            var categoryChildren = category.children.map(function (child) { return ["./" + categoryKey + "/" + child.key + ".md", child.title]; });
            return {
                children: categoryChildren,
                collapsable: false,
                title: categoryTitle
            };
        });
        var extraConfig = {
            exampleSidebar: config
        };
        // Writing extraConfig object as .vuepress/exampleExtra.json
        fs.writeFileSync(this.vuepressExampleConfigPath, JSON.stringify(extraConfig), 'utf-8');
    };
    /**
     * Create example directory if not exist
     */
    ExampleProcessor.prototype.createDir = function () {
        if (!fs.existsSync(this.exampleOutputPath)) {
            fs.mkdirSync(this.exampleOutputPath);
        }
    };
    /**
     * Create example category directory if not exist
     * @param fullPath
     */
    ExampleProcessor.prototype.createDirByName = function (fullPath) {
        if (!fs.existsSync(fullPath)) {
            fs.mkdirSync(fullPath);
        }
    };
    /**
     * Creates the readme file for examples
     * @param hbs
     */
    ExampleProcessor.prototype.createReadMe = function (hbs) {
        var exampleHomePageThemeContent = fs.readFileSync(this.srcExampleHomeTheme, 'utf8');
        var template = hbs.compile(exampleHomePageThemeContent);
        var compiledPage = template(exampleConfig_1["default"]);
        fs.appendFileSync(this.destExampleHomePage, compiledPage, { flag: 'a' });
    };
    ExampleProcessor.prototype.createExamplePage = function (hbs) {
        var _this = this;
        var examplePageThemeContent = fs.readFileSync(this.srcExamplePageTheme, 'utf8');
        var template = hbs.compile(examplePageThemeContent);
        lodash_1.forEach(exampleConfig_1["default"], function (category) {
            var categoryKey = category.key;
            var categoryDir = path.join(_this.exampleOutputPath, categoryKey);
            // Creates the category dir
            _this.createDirByName(categoryDir);
            var categoryChildren = category.children;
            lodash_1.forEach(categoryChildren, function (child) {
                var childKey = child.key;
                var examplePageName = path.join(categoryDir, childKey + ".md");
                var compiledPage = template(child);
                fs.appendFileSync(examplePageName, compiledPage, { flag: 'a' });
            });
        });
    };
    return ExampleProcessor;
}(BaseProcesser_1.BaseProcesser));
exports.ExampleProcessor = ExampleProcessor;
